@@ -14,9 +14,10 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "avibase.h"
+#include "avifmt.h"
 #include "misc/misc.h"
 
 
@@ -62,8 +63,8 @@ avi_at_scenario (AviEdit    *avi_edit,
                 avi_edit->file->start + start_n - avi_edit->offset,
                 MIN (avi_edit->file->length - (start_n - avi_edit->offset),
                                                                 samples_n));
-            samples_n -= avi_edit->file->length - (start_n - avi_edit->offset);
-            start_n += avi_edit->file->length - (start_n - avi_edit->offset);
+          samples_n -= avi_edit->file->length - (start_n - avi_edit->offset);
+          start_n += avi_edit->file->length - (start_n - avi_edit->offset);
         }
       else if (avi_edit->file->data && avi_edit->file->bmih)
         {
@@ -147,7 +148,7 @@ avi_to_scenario (AviEdit        *avi_edit[],
     {
       switch (avi_type (avi_edit[i]))
         {
-          case AVI_STREAM_AUDIO:
+          case AVI_TYPE_AUDIO:
             text = g_strdup_printf ("%d,type,audio\n"
                                     "%d,priority,%u\n"
                                     "%d,language,%X\n",
@@ -155,23 +156,23 @@ avi_to_scenario (AviEdit        *avi_edit[],
                                 i, avi_get_priority (avi_edit[i]),
                                 i, avi_get_language (avi_edit[i]));
             break;
-          case AVI_STREAM_VIDEO:
+          case AVI_TYPE_VIDEO:
             text = g_strdup_printf ("%d,type,video\n"
                                     "%d,rate,%u\n"
                                     "%d,scale,%u\n"
                                     "%d,priority,%u\n"
                                     "%d,language,%X\n"
                                     "%d,bmih,%d,%d,%d,%d,%d\n",
-                                i,
-                                i, avi_get_rate (avi_edit[i]),
-                                i, avi_get_scale (avi_edit[i]),
-                                i, avi_get_priority (avi_edit[i]),
-                                i, avi_get_language (avi_edit[i]),
-                                i,  avi_get_width (avi_edit[i]),
-                                    avi_get_height (avi_edit[i]),
-                                    avi_get_bit_count (avi_edit[i]),
-                                    avi_get_x_pixels_per_meter (avi_edit[i]),
-                                    avi_get_y_pixels_per_meter (avi_edit[i]));
+                        i,
+                        i, avi_get_rate (avi_edit[i]),
+                        i, avi_get_scale (avi_edit[i]),
+                        i, avi_get_priority (avi_edit[i]),
+                        i, avi_get_language (avi_edit[i]),
+                        i,  bmih_get_width (avi_edit[i]->bmih),
+                            bmih_get_height (avi_edit[i]->bmih),
+                            bmih_get_bit_count (avi_edit[i]->bmih),
+                            bmih_get_x_pixels_per_meter (avi_edit[i]->bmih),
+                            bmih_get_y_pixels_per_meter (avi_edit[i]->bmih));
             break;
           default:
             g_free (scenario);
@@ -209,7 +210,7 @@ avi_to_scenario (AviEdit        *avi_edit[],
       for (streams = 0; avi_edit[streams]; streams++);
       /* ja:最も1秒間のフレーム数が少ないストリームを探す */
       for (current = 0; current < streams; current++)
-        if (avi_type (avi_edit[current]) == AVI_STREAM_VIDEO)
+        if (avi_type (avi_edit[current]) == AVI_TYPE_VIDEO)
           break;
       if (current >= streams)
         {
@@ -219,18 +220,11 @@ avi_to_scenario (AviEdit        *avi_edit[],
       else
         {
           for (i = 0; i < streams; i++)
-            if (avi_type (avi_edit[i]) == AVI_STREAM_VIDEO
-#ifdef G_HAVE_GINT64
-                        && (gint64)avi_get_rate (avi_edit[i])
+            if (avi_type (avi_edit[i]) == AVI_TYPE_VIDEO
+                        && (glonglong)avi_get_rate (avi_edit[i])
                                             * avi_get_scale (avi_edit[current])
-                            < (gint64)avi_get_rate (avi_edit[current])
+                            < (glonglong)avi_get_rate (avi_edit[current])
                                                 * avi_get_scale (avi_edit[i]))
-#else /* not G_HAVE_GINT64 */
-                        && avi_get_rate (avi_edit[i])
-                                            * avi_get_scale (avi_edit[current])
-                            < avi_get_rate (avi_edit[current])
-                                                * avi_get_scale (avi_edit[i]))
-#endif /* not G_HAVE_GINT64 */
               current = i;
             times = avi_length_time (avi_edit[current])
                                             / avi_length (avi_edit[current]);
@@ -270,7 +264,7 @@ avi_to_scenario (AviEdit        *avi_edit[],
             {
               pos[current]++;
               if (avi_length (avi_edit[current]) <= pos[current])
-                current=-1;
+                current = -1;
             }
           else
             {
@@ -318,7 +312,7 @@ avi_from_scenario (const gchar *scenario)
     if (text[i] != '\\' || text[i + 1] != '\n')
       text[j++] = text[i];
   text[j] = '\0';
-  lines = g_strsplit (text, "\n", G_MAXINT);
+  lines = g_strsplit (text, "\n", 0);
   g_free (text);
   for (i = 0; lines[i]; i++)
     {
@@ -350,7 +344,7 @@ avi_from_scenario (const gchar *scenario)
               }
           }
       g_strstrip (lines[i]);
-      cmd = g_strsplit (lines[i], "\n", G_MAXINT);
+      cmd = g_strsplit (lines[i], "\n", 0);
       for (j = 0; cmd[j]; j++)
         {
           gint leng;
@@ -382,11 +376,11 @@ avi_from_scenario (const gchar *scenario)
           if (g_strcasecmp (cmd[1], "type") == 0 && cmd[2])
             {
               if (g_strcasecmp (cmd[2], "audio") == 0)
-                avi_edit[stream]->type = AVI_STREAM_AUDIO;
+                avi_edit[stream]->type = AVI_TYPE_AUDIO;
               else if (g_strcasecmp (cmd[2], "video") == 0)
-                avi_edit[stream]->type = AVI_STREAM_VIDEO;
+                avi_edit[stream]->type = AVI_TYPE_VIDEO;
             }
-          else if (g_strcasecmp (cmd[1], "rate") == 0&& cmd[2])
+          else if (g_strcasecmp (cmd[1], "rate") == 0 && cmd[2])
             {
               if (misc_str_to_val (&value, cmd[2], 10, FALSE))
                 avi_set_rate (avi_edit[stream], value);
@@ -399,12 +393,12 @@ avi_from_scenario (const gchar *scenario)
           else if (g_strcasecmp (cmd[1], "priority") == 0 && cmd[2])
             {
               if (misc_str_to_val (&value, cmd[2], 10, FALSE))
-                avi_set_priority (avi_edit[stream], value);
+                avi_set_priority (avi_edit[stream], (guint16)value);
             }
           else if (g_strcasecmp (cmd[1], "language") == 0 && cmd[2])
             {
               if (misc_str_to_val (&value, cmd[2], 16, FALSE))
-                avi_set_language (avi_edit[stream], value);
+                avi_set_language (avi_edit[stream], (guint16)value);
             }
           else if (g_strcasecmp (cmd[1], "name") == 0 && cmd[2])
             {
@@ -486,9 +480,9 @@ avi_from_scenario (const gchar *scenario)
                                         ? &avi_edit[stream]->language : NULL,
                                 !avi_get_name (avi_edit[stream])
                                         ? &avi_edit[stream]->name : NULL);
-              if (avi_type (avi_edit[stream]) == 0)
+              if (avi_type (avi_edit[stream]) == AVI_TYPE_UNKNOWN)
                 {
-                  avi_edit[stream]->type=type;
+                  avi_edit[stream]->type = type;
                 }
               else if (avi_type (avi_edit[stream]) != type)
                 {
@@ -517,7 +511,7 @@ avi_from_scenario (const gchar *scenario)
                       /* ja:先頭 */
                       avi_edit[stream]->file = avi_file;
                     }
-                  else if (g_strcmp (avi_edit[stream]->file->name,
+                  else if (g_strfilecmp (avi_edit[stream]->file->name,
                                                         avi_file->name) == 0
                       && avi_edit[stream]->file->start
                         + avi_edit[stream]->file->length == avi_file->start)
@@ -646,7 +640,7 @@ avi_from_scenario (const gchar *scenario)
           if (avi_edit[i]->file)
             {
               while (avi_edit[i]->file->prev)
-                avi_edit[i]->file=avi_edit[i]->file->prev;
+                avi_edit[i]->file = avi_edit[i]->file->prev;
               for (avi_file = avi_edit[i]->file; avi_file;
                                                     avi_file = avi_file->next)
                 avi_edit[i]->length += avi_file->length;
@@ -658,13 +652,14 @@ avi_from_scenario (const gchar *scenario)
             }
           /* ja:展開後のフォーマット */
           if (avi_edit[i] && !avi_edit[i]->bmih
-                                && avi_type (avi_edit[i]) == AVI_STREAM_VIDEO)
+                                && avi_type (avi_edit[i]) == AVI_TYPE_VIDEO)
             {
               if (avi_edit[i]->file->handler == AVI_STREAM_COMP_DIB)
                 {
                   avi_edit[i]->bmih = g_memdup (avi_edit[i]->file->bmih,
                                     bm_header_bytes (avi_edit[i]->file->bmih));
-                  if (avi_get_compression (avi_edit[i]) == AVI_STREAM_COMP_DIB)
+                  if (bmih_get_compression (avi_edit[i]->bmih)
+                                                        == AVI_STREAM_COMP_DIB)
                     bmih_set_compression (avi_edit[i]->bmih, BI_COMP_RGB);
                   if (bmih_get_size_image (avi_edit[i]->bmih) <= 0)
                     bmih_set_size_image (avi_edit[i]->bmih,
@@ -703,7 +698,7 @@ avi_from_scenario (const gchar *scenario)
                 }
             }
           else if (avi_edit[i] && !avi_edit[i]->wfx
-                                && avi_type (avi_edit[i]) == AVI_STREAM_AUDIO)
+                                && avi_type (avi_edit[i]) == AVI_TYPE_AUDIO)
             {
               if (wfx_get_format_tag (avi_edit[i]->file->wfx)
                                                             == WAVE_FORMAT_PCM)
@@ -718,10 +713,12 @@ avi_from_scenario (const gchar *scenario)
                   avi_edit[i] = NULL;
                 }
             }
-//          g_print("type=%X,rate=%u,scale=%u,length=%d\n",avi_edit[i]->type,avi_edit[i]->rate,avi_edit[i]->scale,avi_edit[i]->length);
-//          for (avi_file=avi_edit[i]->file;avi_file!=NULL;
-//                                                  avi_file=avi_file->next)
-//              g_print("%s,start=%d,length=%d\n",avi_file->name,avi_file->start,avi_file->length);
+#ifdef XXX
+          g_print("type=%X,rate=%u,scale=%u,length=%d\n",avi_edit[i]->type,avi_edit[i]->rate,avi_edit[i]->scale,avi_edit[i]->length);
+          for (avi_file=avi_edit[i]->file;avi_file!=NULL;
+                                                  avi_file=avi_file->next)
+              g_print("%s,start=%d,length=%d\n",avi_file->name,avi_file->start,avi_file->length);
+#endif
         }
       j = 0;
       for (i = 0; i < count; i++)
