@@ -1,6 +1,6 @@
 /*
     avicore
-    copyright (c) 1998-2004 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2005 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef __ICM_H__
 #define __ICM_H__
@@ -22,20 +22,11 @@
 
 #include "common.h"
 #include "bitmap.h"
-#include "chunk.h"
-#ifdef W32CODECDIR
-# include "icm32.h"
-#endif /* W32CODECDIR */
-#ifdef G_OS_WIN32
-# include <tchar.h>
-# include <windows.h>
-# include <vfw.h>
-#endif /* G_OS_WIN32 */
 
 
 #ifdef __cplusplus
 extern "C" {
-#endif
+#endif /* __cplusplus */
 
 
 #define ICM_ATTR_NATIVE             0
@@ -64,87 +55,7 @@ extern "C" {
 #define ICM_DECOMPRESS_NOTKEYFRAME  0x08000000
 
 
-typedef struct IcmDriver_Tag
-{
-#ifdef G_OS_WIN32
-  HMODULE hLib;
-  LONG (WINAPI *DriverProc)(DWORD  dwDriverId,
-                            HANDLE hdrvr,
-                            UINT   msg,
-                            LONG   lParam1,
-                            LONG   lParam2);
-#endif /* G_OS_WIN32 */
-#ifdef W32CODECDIR
-  PE_image *hLib;
-  LONG WINAPI (*DriverProc)(DWORD  dwDriverId,
-                            HANDLE hdrvr,
-                            UINT   msg,
-                            LONG   lParam1,
-                            LONG   lParam2);
-#endif /* W32CODECDIR */
-#if !defined (G_OS_WIN32) && !defined (W32CODECDIR)
-  guint8 dummy;
-#endif /* !defined (G_OS_WIN32) && !defined (W32CODECDIR) */
-} IcmDriver;
-
-
-typedef struct IcmObject_Tag
-{
-  gint counter;
-  guint32 handler;
-  gint mode;
-  BitmapInfoHeader *bmih_in;
-  BitmapInfoHeader *bmih_out;
-  gint frame;
-  gsize size;
-  gint quality;
-  gpointer prev;
-  gsize prev_size;
-  IcmDriver *icm_driver;
-#if defined (G_OS_WIN32) || defined (W32CODECDIR)
-  DWORD dwDriverId;
-#endif /* defined (G_OS_WIN32) || defined (W32CODECDIR) */
-} IcmObject;
-
-
-typedef struct IcmInfo_Tag
-{
-  gchar *name;
-  guint32 handler;
-  guint32 flags;
-  guint32 attribute;
-} IcmInfo;
-
-
-/******************************************************************************
-*                                                                             *
-* ja:ICMマクロ                                                                *
-*                                                                             *
-******************************************************************************/
-/*  ja:Codecの参照数を増やす
-    icm_object,IcmObject
-           RET,TRUE:正常終了,FALSE:エラー                                   */
-#define icm_ref(icm_object)                                                 \
-        ((icm_object)!=NULL?((icm_object)->icm_object->counter++,TRUE):FALSE)
-
-
-/*  ja:Codecの参照数を減らす
-    icm_object,IcmObject
-           RET,TRUE:正常終了,FALSE:エラー                                   */
-#define icm_unref(icm_object) icm_close(icm_object)
-
-
-/*  ja:Codecをコピーする
-    icm_object,IcmObject
-           RET,IcmObject,NULL:エラー                                        */
-#define icm_dup(icm_object) ((icm_object)!=NULL                             \
-                    ?icm_open((icm_object)->handler,(icm_object)->mode):NULL)
-
-
-/*  ja:Codecの4文字コードを取得する
-    icm_object,IcmObject
-           RET,4文字コード,0:エラー                                         */
-#define icm_get_handler(icm_object) ((icm_object)?(icm_object)->handler:0)
+typedef struct _IcmObject IcmObject;
 
 
 /******************************************************************************
@@ -176,11 +87,11 @@ gchar *
 icm_handler_to_string (const guint32 handler);
 
 
-/*  ja:文字列→4文字コード
+/*  ja:4文字コード←文字列
     text,文字列
      RET,4文字コード                                                        */
 guint32
-icm_string_to_handler (const gchar *text);
+icm_handler_from_string (const gchar *text);
 
 
 /******************************************************************************
@@ -210,15 +121,65 @@ gboolean
 icm_close (IcmObject *icm_object);
 
 
-/*  ja:Codecの情報を取得する
+/*  ja:Codecの参照数を増やす
     icm_object,IcmObject
-      icm_info,情報
            RET,TRUE:正常終了,FALSE:エラー                                   */
 gboolean
-icm_get_info (IcmObject *icm_object,
-              IcmInfo   *icm_info);
+icm_ref (IcmObject *icm_object);
 
 
+/*  ja:Codecの参照数を減らす
+    icm_object,IcmObject
+           RET,TRUE:正常終了,FALSE:エラー                                   */
+gboolean
+icm_unref (IcmObject *icm_object);
+
+
+/*  ja:Codecをコピーする
+    icm_object,IcmObject
+           RET,IcmObject,NULL:エラー                                        */
+IcmObject *
+icm_dup (IcmObject *icm_object);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:ICM情報                                                                  *
+*                                                                             *
+******************************************************************************/
+/*  ja:Codecの4文字コードを取得する
+    icm_object,IcmObject
+           RET,4文字コード,0:エラー                                         */
+guint32
+icm_get_handler (IcmObject *icm_object);
+
+
+/*  ja:Codecの名前を取得する
+    icm_object,IcmObject
+           RET,名前,NULL:エラー                                             */
+const gchar *
+icm_get_name (IcmObject *icm_object);
+
+
+/*  ja:Codecのフラグを取得する
+    icm_object,IcmObject
+           RET,フラグ                                                       */
+gint
+icm_get_flags (IcmObject *icm_object);
+
+
+/*  ja:Codecの属性を取得する
+    icm_object,IcmObject
+           RET,ICM_ATTR_NATIVE,ICM_ATTR_WIN32                               */
+gint
+icm_get_attribute (IcmObject *icm_object);
+
+
+/******************************************************************************
+*                                                                             *
+* ja:ICMパラメータ                                                            *
+*                                                                             *
+******************************************************************************/
 /*  ja:パラメータのサイズを取得する
     icm_object,IcmObject
            RET,サイズ                                                       */
@@ -449,7 +410,7 @@ icm_decompress (IcmObject   *icm_object,
 
 #ifdef __cplusplus
 }
-#endif
+#endif /* __cplusplus */
 
 
-#endif
+#endif /* __ICM_H__ */
