@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "command.h"
 #include "file.h"
@@ -24,6 +24,7 @@
 #include "sigfile.h"
 #include "size.h"
 #include "thread.h"
+#include "version.h"
 #if GTK_CHECK_VERSION(2,4,0)
 # include "avicore/avifileextra.h"
 #else /* not GTK_CHECK_VERSION(2,4,0) */
@@ -31,9 +32,9 @@
 #endif /* not GTK_CHECK_VERSION(2,4,0) */
 #include "misc/fileio.h"
 #include "misc/misc.h"
-#include "misc/misc_conf.h"
-#include "misc/misc_history.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzconf.h"
+#include "orz/orzhistory.h"
+#include "orz/orzmdi.h"
 #ifdef G_OS_WIN32
 # include <gdk/gdkwin32.h>
 #endif /* G_OS_WIN32 */
@@ -45,9 +46,8 @@
 *                                                                             *
 ******************************************************************************/
 void
-command_new (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_new (GtkWidget *widget,
+             gpointer   user_data)
 {
 #ifdef USE_THREAD
   g_thread_create ((GThreadFunc)file_open_edit, NULL, TRUE, NULL);
@@ -88,9 +88,8 @@ command_open_ok (GtkWidget     *widget,
 
 
 void
-command_open (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_open (GtkWidget *widget,
+              gpointer   user_data)
 {
   gchar *path;
   CommandOpenOk cmd_ok;
@@ -162,22 +161,20 @@ command_open (gpointer   callback_data,
 
 
 void
-command_close (gpointer   callback_data,
-               guint      callback_action,
-               GtkWidget *widget)
+command_close (GtkWidget *widget,
+               gpointer   user_data)
 {
   gint page;
 
   if ((page = gtk_notebook_get_current_page (GTK_NOTEBOOK (mdi))) >= 0
-    && prompt_close ((VmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), page)))
+    && prompt_close ((VmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), page)))
     gtk_notebook_remove_page (GTK_NOTEBOOK (mdi), page);
 }
 
 
 void
-command_save (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_save (GtkWidget *widget,
+              gpointer   user_data)
 {
   gchar *path;
   gint i = 0;
@@ -189,7 +186,7 @@ command_save (gpointer   callback_data,
   GtkWidget *extra;
 #endif /* GTK_CHECK_VERSION(2,4,0) */
 
-  vmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  vmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   if (vmaid->avi_edit[0])
     avi_edit[i++] = vmaid->avi_edit[0];
   if (vmaid->avi_edit[1])
@@ -247,12 +244,12 @@ command_save (gpointer   callback_data,
       if (avi_save_is_all (avi_edit, cmd_ok.avi_save))
         {
           /* ja:すべて保存されるとき */
-          misc_mdi_set_edited (MISC_MDI (mdi),
-                misc_mdi_get_page_from_data (MISC_MDI (mdi), vmaid), FALSE);
+          orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), vmaid), FALSE);
           delete_list (&vmaid->undo);
           delete_list (&vmaid->redo);
           set_menu_bar (vmaid);
-          misc_history_add_file (MISC_HISTORY (history), cmd_ok.file);
+          orz_history_add_file (ORZ_HISTORY (history), cmd_ok.file);
         }
       file_save = g_malloc (sizeof (FileSave));
       file_save->file = cmd_ok.file;
@@ -276,75 +273,76 @@ command_save (gpointer   callback_data,
 
 
 void
-command_property (gpointer   callback_data,
-                  guint      callback_action,
-                  GtkWidget *widget)
+command_property (GtkWidget *widget,
+                  gpointer   user_data)
 {
   VmaidWindow *vmaid;
-  PropertyDialog prop;
+  PropertyConfig propcfg;
 
-  vmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
-  g_memset (&prop, 0, sizeof (PropertyDialog));
-  prop.rate = vmaid->rate;
-  prop.scale = vmaid->scale;
+  vmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
+  g_memset (&propcfg, 0, sizeof (PropertyConfig));
+  propcfg.rate = vmaid->rate;
+  propcfg.scale = vmaid->scale;
   if (vmaid->avi_edit[0])
     {
-      prop.priority0 = avi_get_priority (vmaid->avi_edit[0]);
-      prop.language0 = avi_get_language (vmaid->avi_edit[0]);
+      propcfg.priority0 = avi_get_priority (vmaid->avi_edit[0]);
+      propcfg.language0 = avi_get_language (vmaid->avi_edit[0]);
       if (avi_get_name (vmaid->avi_edit[0]))
-        prop.name0 = g_strdup (avi_get_name (vmaid->avi_edit[0]));
-      prop.width = avi_get_width (vmaid->avi_edit[0]);
-      prop.height = avi_get_height (vmaid->avi_edit[0]);
-      prop.bit_count = avi_get_bit_count (vmaid->avi_edit[0]);
-      prop.x_pixels_per_meter
+        propcfg.name0 = g_strdup (avi_get_name (vmaid->avi_edit[0]));
+      propcfg.width = avi_get_width (vmaid->avi_edit[0]);
+      propcfg.height = avi_get_height (vmaid->avi_edit[0]);
+      propcfg.bit_count = avi_get_bit_count (vmaid->avi_edit[0]);
+      propcfg.x_pixels_per_meter
                             = avi_get_x_pixels_per_meter (vmaid->avi_edit[0]);
-      prop.y_pixels_per_meter
+      propcfg.y_pixels_per_meter
                             = avi_get_y_pixels_per_meter (vmaid->avi_edit[0]);
     }
   else
     {
-      prop.x_pixels_per_meter = -1;
-      prop.y_pixels_per_meter = -1;
+      propcfg.x_pixels_per_meter = -1;
+      propcfg.y_pixels_per_meter = -1;
     }
   if (vmaid->avi_edit[1])
     {
-      prop.priority1 = avi_get_priority (vmaid->avi_edit[1]);
-      prop.language1 = avi_get_language (vmaid->avi_edit[1]);
+      propcfg.priority1 = avi_get_priority (vmaid->avi_edit[1]);
+      propcfg.language1 = avi_get_language (vmaid->avi_edit[1]);
       if (avi_get_name (vmaid->avi_edit[1]))
-        prop.name1 = g_strdup (avi_get_name (vmaid->avi_edit[1]));
-      prop.samples_per_sec = avi_get_samples_per_sec (vmaid->avi_edit[1]);
-      prop.channels = avi_get_channels (vmaid->avi_edit[1]);
-      prop.bits_per_sample = avi_get_bits_per_sample (vmaid->avi_edit[1]);
+        propcfg.name1 = g_strdup (avi_get_name (vmaid->avi_edit[1]));
+      propcfg.samples_per_sec = avi_get_samples_per_sec (vmaid->avi_edit[1]);
+      propcfg.channels = avi_get_channels (vmaid->avi_edit[1]);
+      propcfg.bits_per_sample = avi_get_bits_per_sample (vmaid->avi_edit[1]);
     }
-  if (property_dialog(&prop))
+  if (property_dialog (&propcfg))
     {
-      vmaid->rate = prop.rate;
-      vmaid->scale = prop.scale;
+      vmaid->rate = propcfg.rate;
+      vmaid->scale = propcfg.scale;
       if (vmaid->avi_edit[0])
         {
-          avi_set_priority (vmaid->avi_edit[0], prop.priority0);
-          avi_set_language (vmaid->avi_edit[0], prop.language0);
-          avi_set_name (vmaid->avi_edit[0], prop.name0);
-          avi_set_rate (vmaid->avi_edit[0], prop.rate);
-          avi_set_scale (vmaid->avi_edit[0], prop.scale);
-          avi_set_width (vmaid->avi_edit[0], prop.width);
-          avi_set_height (vmaid->avi_edit[0], prop.height);
-          avi_set_bit_count (vmaid->avi_edit[0], prop.bit_count);
+          avi_set_priority (vmaid->avi_edit[0], propcfg.priority0);
+          avi_set_language (vmaid->avi_edit[0], propcfg.language0);
+          avi_set_name (vmaid->avi_edit[0], propcfg.name0);
+          avi_set_rate (vmaid->avi_edit[0], propcfg.rate);
+          avi_set_scale (vmaid->avi_edit[0], propcfg.scale);
+          avi_set_width (vmaid->avi_edit[0], propcfg.width);
+          avi_set_height (vmaid->avi_edit[0], propcfg.height);
+          avi_set_bit_count (vmaid->avi_edit[0], propcfg.bit_count);
           avi_set_x_pixels_per_meter (vmaid->avi_edit[0],
-                                                    prop.x_pixels_per_meter);
+                                                propcfg.x_pixels_per_meter);
           avi_set_y_pixels_per_meter (vmaid->avi_edit[0],
-                                                    prop.y_pixels_per_meter);
-          g_free (prop.name0);
+                                                propcfg.y_pixels_per_meter);
+          g_free (propcfg.name0);
         }
       if (vmaid->avi_edit[1])
         {
-          avi_set_priority (vmaid->avi_edit[1], prop.priority1);
-          avi_set_language (vmaid->avi_edit[1], prop.language1);
-          avi_set_name (vmaid->avi_edit[1], prop.name1);
-          avi_set_samples_per_sec (vmaid->avi_edit[1], prop.samples_per_sec);
-          avi_set_channels (vmaid->avi_edit[1], prop.channels);
-          avi_set_bits_per_sample (vmaid->avi_edit[1], prop.bits_per_sample);
-          g_free (prop.name1);
+          avi_set_priority (vmaid->avi_edit[1], propcfg.priority1);
+          avi_set_language (vmaid->avi_edit[1], propcfg.language1);
+          avi_set_name (vmaid->avi_edit[1], propcfg.name1);
+          avi_set_samples_per_sec (vmaid->avi_edit[1],
+                                                    propcfg.samples_per_sec);
+          avi_set_channels (vmaid->avi_edit[1], propcfg.channels);
+          avi_set_bits_per_sample (vmaid->avi_edit[1],
+                                                    propcfg.bits_per_sample);
+          g_free (propcfg.name1);
         }
       vmaid->cursor.stream = vmaid->avi_edit[0] ? 0 : 1;
       vmaid->cursor.frame = 0;
@@ -360,9 +358,8 @@ command_property (gpointer   callback_data,
 
 
 void
-command_exit (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_exit (GtkWidget *widget,
+              gpointer   user_data)
 {
   GdkEvent event;
 
@@ -374,39 +371,35 @@ command_exit (gpointer   callback_data,
 
 
 void
-command_undo (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_undo (GtkWidget *widget,
+              gpointer   user_data)
 {
-  history_operation ((VmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1),
+  history_operation ((VmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1),
                                                                         FALSE);
 }
 
 
 void
-command_redo (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_redo (GtkWidget *widget,
+              gpointer   user_data)
 {
-  history_operation ((VmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1),
+  history_operation ((VmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1),
                                                                         TRUE);
 }
 
 
 void
-command_cut (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_cut (GtkWidget *widget,
+             gpointer   user_data)
 {
-  command_copy (callback_data, callback_action, widget);
-  command_delete (callback_data, callback_action, widget);
+  command_copy (widget, user_data);
+  command_delete (widget, user_data);
 }
 
 
 void
-command_copy (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_copy (GtkWidget *widget,
+              gpointer   user_data)
 {
   gint i = 0, start, end, length, max;
   AviEdit *avi_edit[3];
@@ -417,7 +410,7 @@ command_copy (gpointer   callback_data,
                                                             GDK_CURRENT_TIME))
     {
 #endif /* not G_OS_WIN32 */
-      vmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+      vmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
       /* ja:ビデオ */
       if (MIN (vmaid->cursor.stream, vmaid->select.stream) == 0)
         {
@@ -433,21 +426,12 @@ command_copy (gpointer   callback_data,
       if (MAX (vmaid->cursor.stream, vmaid->select.stream) == 1)
         {
           max = avi_length (vmaid->avi_edit[1]);
-#ifdef G_HAVE_GINT64
-          start = MAX (avi_time_to_sample (vmaid->avi_edit[1],
-                (gint64)MIN (vmaid->cursor.frame, vmaid->select.frame) * 1000
-                                            * vmaid->scale / vmaid->rate), 0);
-          end = MIN (avi_time_to_sample (vmaid->avi_edit[1],
-                (gint64)MAX (vmaid->cursor.frame, vmaid->select.frame) * 1000
-                                        * vmaid->scale / vmaid->rate), max);
-#else /* not G_HAVE_GINT64 */
-          start = MAX (avi_time_to_sample (vmaid->avi_edit[1],
-                        MIN (vmaid->cursor. frame, vmaid->select. frame) * 1000
-                                            * vmaid->scale / vmaid->rate), 0);
-          end = MIN (avi_time_to_sample (vmaid->avi_edit[1],
-                        MAX (vmaid->cursor. frame, vmaid->select. frame) * 1000
-                                        * vmaid->scale / vmaid->rate), max);
-#endif /* not G_HAVE_GINT64 */
+          start = MAX (avi_time_to_sample (vmaid->avi_edit[1], (gint)
+            ((glonglong)MIN (vmaid->cursor.frame, vmaid->select.frame) * 1000
+                                            * vmaid->scale / vmaid->rate)), 0);
+          end = MIN (avi_time_to_sample (vmaid->avi_edit[1], (gint)
+            ((glonglong)MAX (vmaid->cursor.frame, vmaid->select.frame) * 1000
+                                        * vmaid->scale / vmaid->rate)), max);
           length = end - start;
           if (length > 0 && (avi_edit[i]
                             = avi_copy (vmaid->avi_edit[1], start, length)))
@@ -502,9 +486,8 @@ command_copy (gpointer   callback_data,
 
 
 void
-command_paste (gpointer   callback_data,
-               guint      callback_action,
-               GtkWidget *widget)
+command_paste (GtkWidget *widget,
+               gpointer   user_data)
 {
 #ifdef G_OS_WIN32
   gchar *scenario = NULL;
@@ -542,28 +525,31 @@ command_paste (gpointer   callback_data,
 
 
 void
-command_delete (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_delete (GtkWidget *widget,
+                gpointer   user_data)
 {
   gboolean result = TRUE;
   gint i, start, end, length, max, sx;
   VmaidHistory *d;
   VmaidWindow *vmaid;
 
-  vmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  vmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   /* ja:UNDOのための処理 */
-  d = g_malloc (sizeof (VmaidHistory));
+  d = g_malloc0 (sizeof (VmaidHistory));
   for (i = 0; i < 2; i++)
-    {
-      d->avi_edit[i] = NULL;
-      if (vmaid->avi_edit[i]
+    if (vmaid->avi_edit[i]
                         && !(d->avi_edit[i] = avi_clone (vmaid->avi_edit[i])))
-        result = FALSE;
-    }
+      result = FALSE;
   if (!result)
     {
-      misc_message_box ("Video maid", _("AVI Clone Error"), 0, _("OK"), NULL);
+      GtkWidget *dialog;
+
+      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("AVI Clone Error"));
+      gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
       for (i = 0; i < 2; i++)
         if (d->avi_edit[i])
           avi_release (d->avi_edit[i]);
@@ -595,21 +581,12 @@ command_delete (gpointer   callback_data,
   if (MAX (vmaid->cursor.stream, vmaid->select.stream) == 1)
     {
       max = avi_length (vmaid->avi_edit[1]);
-#ifdef G_HAVE_GINT64
-      start = MAX (avi_time_to_sample (vmaid->avi_edit[1],
-                (gint64)MIN (vmaid->cursor.frame, vmaid->select.frame) * 1000
-                                            * vmaid->scale / vmaid->rate), 0);
-      end = MIN (avi_time_to_sample (vmaid->avi_edit[1],
-                (gint64)MAX (vmaid->cursor.frame, vmaid->select.frame) * 1000
-                                        * vmaid->scale / vmaid->rate), max);
-#else /* not G_HAVE_GINT64 */
-      start = MAX (avi_time_to_sample (vmaid->avi_edit[1],
-                        MIN (vmaid->cursor. frame, vmaid->select. frame) * 1000
-                                            * vmaid->scale / vmaid->rate), 0);
-      end = MIN (avi_time_to_sample (vmaid->avi_edit[1],
-                        MAX (vmaid->cursor. frame, vmaid->select. frame) * 1000
-                                        * vmaid->scale / vmaid->rate), max);
-#endif /* not G_HAVE_GINT64 */
+      start = MAX (avi_time_to_sample (vmaid->avi_edit[1], (gint)
+            ((glonglong)MIN (vmaid->cursor.frame, vmaid->select.frame) * 1000
+                                            * vmaid->scale / vmaid->rate)), 0);
+      end = MIN (avi_time_to_sample (vmaid->avi_edit[1], (gint)
+            ((glonglong)MAX (vmaid->cursor.frame, vmaid->select.frame) * 1000
+                                        * vmaid->scale / vmaid->rate)), max);
       if (start == 0 && end == max)
         {
           if (!avi_release (vmaid->avi_edit[1]))
@@ -625,7 +602,14 @@ command_delete (gpointer   callback_data,
     }
   if (!result)
     {
-      misc_message_box ("Video maid", _("AVI Delete Error"), 0, _("OK"), NULL);
+      GtkWidget *dialog;
+
+      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_WARNING, GTK_BUTTONS_OK,
+                            _("AVI Delete Error"));
+      gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
       for (i = 0; i < 2; i++)
         {
           if (vmaid->avi_edit[i])
@@ -641,15 +625,16 @@ command_delete (gpointer   callback_data,
   max = get_max_frame (vmaid, -1) + 1;
   sx = MAX ((vmaid->drawing->allocation.width - 4) / vmaid->width - 2, 1);
   vmaid->cursor.frame = (vmaid->avi_edit[0] || vmaid->avi_edit[1])
-                        ? MIN(vmaid->cursor.frame, vmaid->select.frame) : 0;
+                        ? MIN (vmaid->cursor.frame, vmaid->select.frame) : 0;
   vmaid->cursor.stream = !vmaid->avi_edit[0] && !vmaid->avi_edit[1]
                                             ? -1 : vmaid->avi_edit[0] ? 0 : 1;
   vmaid->select.stream = -1;
   if (vmaid->cursor.frame > max)
     vmaid->cursor.frame = max;
+  /* ja:キャレットが表示されるように調整 */
   if (vmaid->top > vmaid->cursor.frame)
-    vmaid->top = vmaid->cursor.frame;
-  else if (vmaid->top < vmaid->cursor.frame - sx)
+    vmaid->top = MIN (vmaid->cursor.frame, max - sx);
+  if (vmaid->top < vmaid->cursor.frame - sx)
     vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
   /* ja:メニュー,ステートメント,子ウインドウ */
   set_menu_bar (vmaid);
@@ -662,40 +647,39 @@ command_delete (gpointer   callback_data,
   misc_set_scroll_bar (vmaid->hscroll,
                                     G_CALLBACK (signal_value_changed_hscroll),
                                                 vmaid, 0, max, sx, vmaid->top);
-  misc_mdi_set_edited (MISC_MDI (mdi),
-                    misc_mdi_get_page_from_data (MISC_MDI (mdi), vmaid), TRUE);
+  orz_mdi_set_edited (ORZ_MDI (mdi),
+                    orz_mdi_get_page_from_data (ORZ_MDI (mdi), vmaid), TRUE);
 }
 
 
 void
-command_jump (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_jump (GtkWidget *widget,
+              gpointer   user_data)
 {
   gint sx, top;
-  JumpDialog jump;
+  JumpConfig jmpcfg;
   VmaidCursor cursor, select;
   VmaidWindow *vmaid;
 
-  vmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  vmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   cursor = vmaid->cursor;
   select = vmaid->select;
   top = vmaid->top;
-  jump.frame = vmaid->cursor.frame;
-  jump.max = get_max_frame (vmaid, -1) + 1;
-  jump.rate = vmaid->rate;
-  jump.scale = vmaid->scale;
-  if (jump_dialog (&jump))
+  jmpcfg.frame = vmaid->cursor.frame;
+  jmpcfg.max = get_max_frame (vmaid, -1) + 1;
+  jmpcfg.rate = vmaid->rate;
+  jmpcfg.scale = vmaid->scale;
+  if (jump_dialog (&jmpcfg))
     {
-      vmaid->cursor.frame = jump.frame;
+      vmaid->cursor.frame = jmpcfg.frame;
       sx = MAX ((vmaid->drawing->allocation.width - 4) / vmaid->width - 2, 1);
       /* ja:キャレットが表示されるように調整 */
       if (vmaid->top > vmaid->cursor.frame)
-        vmaid->top = vmaid->cursor.frame;
-      else if (vmaid->top < vmaid->cursor.frame - sx)
+        vmaid->top = MIN (vmaid->cursor.frame, jmpcfg.max - sx);
+      if (vmaid->top < vmaid->cursor.frame - sx)
         vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
       /* ja:ジャンプの例外 ジャンプ先のフレームを表示する */
-      if (vmaid->cursor.frame < jump.max
+      if (vmaid->cursor.frame < jmpcfg.max
                                     && vmaid->top + sx <= vmaid->cursor.frame)
         vmaid->top = vmaid->cursor.frame - sx + 1;
       if (vmaid->cursor.frame == vmaid->select.frame)
@@ -707,7 +691,7 @@ command_jump (gpointer   callback_data,
       if (vmaid->top != top)
         misc_set_scroll_bar (vmaid->hscroll,
                                     G_CALLBACK (signal_value_changed_hscroll),
-                                        vmaid, 0, jump. max, sx, vmaid->top);
+                                        vmaid, 0, jmpcfg.max, sx, vmaid->top);
       clear_sel (vmaid, &cursor, &select, top);
       draw_caret (vmaid, &cursor);
     }
@@ -715,15 +699,14 @@ command_jump (gpointer   callback_data,
 
 
 void
-command_all (gpointer   callback_data,
-             guint      callback_action,
-             GtkWidget *widget)
+command_all (GtkWidget *widget,
+             gpointer   user_data)
 {
   gint max, sx, top;
   VmaidCursor cursor, select;
   VmaidWindow *vmaid;
 
-  vmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
+  vmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
   if (vmaid->avi_edit[0] || vmaid->avi_edit[1])
     {
       cursor = vmaid->cursor;
@@ -737,8 +720,8 @@ command_all (gpointer   callback_data,
       vmaid->cursor.stream = vmaid->avi_edit[1] ? 1 : 0;
       /* ja:キャレットが表示されるように調整 */
       if (vmaid->top > vmaid->cursor.frame)
-        vmaid->top = vmaid->cursor.frame;
-      else if (vmaid->top < vmaid->cursor.frame - sx)
+        vmaid->top = MIN (vmaid->cursor.frame, max - sx);
+      if (vmaid->top < vmaid->cursor.frame - sx)
         vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
       if (select.stream< 0 )
         set_menu_bar (vmaid);
@@ -753,34 +736,33 @@ command_all (gpointer   callback_data,
 
 
 void
-command_size (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_size (GtkWidget *widget,
+              gpointer   user_data)
 {
-  SizeDialog size;
+  SizeConfig sizecfg;
   VmaidWindow *vmaid;
 
-  vmaid = misc_mdi_get_data (MISC_MDI (mdi), -1);
-  size.view = default_view;
-  size.ratio = default_ratio;
-  size.width = vmaid->width;
-  size.height = vmaid->height;
+  vmaid = orz_mdi_get_data (ORZ_MDI (mdi), -1);
+  sizecfg.view = default_view;
+  sizecfg.ratio = default_ratio;
+  sizecfg.width = vmaid->width;
+  sizecfg.height = vmaid->height;
   if (vmaid->avi_edit[0])
     {
-      size.def_width = avi_get_width (vmaid->avi_edit[0]);
-      size.def_height  =avi_get_height (vmaid->avi_edit[0]);
+      sizecfg.def_width = avi_get_width (vmaid->avi_edit[0]);
+      sizecfg.def_height = avi_get_height (vmaid->avi_edit[0]);
     }
   else
     {
-      size.def_width = 0;
-      size.def_height = 0;
+      sizecfg.def_width = 0;
+      sizecfg.def_height = 0;
     }
-  if (size_dialog (&size))
+  if (size_dialog (&sizecfg))
     {
-      default_view = size.view;
-      default_ratio = size.ratio;
-      vmaid->width = size.width;
-      vmaid->height = size.height;
+      default_view = sizecfg.view;
+      default_ratio = sizecfg.ratio;
+      vmaid->width = sizecfg.width;
+      vmaid->height = sizecfg.height;
       gtk_widget_set_usize (vmaid->drawing, vmaid->width * 3 + 4,
                         system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
                             + (vmaid->avi_edit[1] ? 1 : 0)) * vmaid->height);
@@ -790,52 +772,46 @@ command_size (gpointer   callback_data,
 }
 
 
-static void
-command_conf_ok (GtkWidget *widget,
-                 GtkWidget *dialog)
-{
-  misc_history_set_num (MISC_HISTORY (history),
-                                misc_conf_get_history (MISC_CONF (dialog)));
-  newfile = misc_conf_get_newfile (MISC_CONF (dialog));
-  second = misc_conf_get_second (MISC_CONF (dialog));
-  misc_conf_get_size (MISC_CONF (dialog), &def_width, &def_height);
-  n_pos = misc_conf_get_tab (MISC_CONF (dialog));
-  gtk_widget_destroy (dialog);
-  /* ja:ノートの位置 */
-  gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
-}
-
-
 void
-command_conf (gpointer   callback_data,
-              guint      callback_action,
-              GtkWidget *widget)
+command_conf (GtkWidget *widget,
+              gpointer   user_data)
 {
   GtkWidget *dialog;
 
-  dialog = misc_conf_new ();
-  g_signal_connect (G_OBJECT (dialog), "destroy",
-                                            G_CALLBACK (gtk_main_quit), NULL);
-  g_signal_connect (G_OBJECT (MISC_CONF (dialog)->ok_button),
-                            "clicked", G_CALLBACK (command_conf_ok), dialog);
-  g_signal_connect_swapped (G_OBJECT (MISC_CONF (dialog)->cancel_button),
-            "clicked", G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
-  misc_conf_set_history (MISC_CONF(dialog),
-                                misc_history_get_num (MISC_HISTORY (history)));
-  misc_conf_set_newfile (MISC_CONF(dialog), newfile);
-  misc_conf_set_second (MISC_CONF(dialog), second);
-  misc_conf_set_size (MISC_CONF(dialog), def_width, def_height);
-  misc_conf_set_tab (MISC_CONF(dialog), n_pos);
-  gtk_widget_show (dialog);
-  gtk_grab_add (dialog);
-  gtk_main ();
+  dialog = orz_conf_new ();
+  gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (window));
+  orz_conf_set_history (ORZ_CONF (dialog),
+                                orz_history_get_num (ORZ_HISTORY (history)));
+  orz_conf_set_newfile (ORZ_CONF (dialog), newfile);
+  orz_conf_set_second (ORZ_CONF (dialog), second);
+  orz_conf_set_size (ORZ_CONF (dialog), def_width, def_height);
+  orz_conf_set_tab (ORZ_CONF (dialog), n_pos);
+  if (gtk_dialog_run (GTK_DIALOG (dialog)) == GTK_RESPONSE_OK)
+    {
+      orz_history_set_num (ORZ_HISTORY (history),
+                                    orz_conf_get_history (ORZ_CONF (dialog)));
+      newfile = orz_conf_get_newfile (ORZ_CONF (dialog));
+      second = orz_conf_get_second (ORZ_CONF (dialog));
+      orz_conf_get_size (ORZ_CONF (dialog), &def_width, &def_height);
+      n_pos = orz_conf_get_tab (ORZ_CONF (dialog));
+      /* ja:ノートの位置 */
+      gtk_notebook_set_tab_pos (GTK_NOTEBOOK (mdi), n_pos);
+    }
+  gtk_widget_destroy (dialog);
 }
 
 
 void
-command_cancel (gpointer   callback_data,
-                guint      callback_action,
-                GtkWidget *widget)
+command_version (GtkWidget *widget,
+                 gpointer   user_data)
+{
+  version_dialog ();
+}
+
+
+void
+command_cancel (GtkWidget *widget,
+                gpointer   user_data)
 {
   thread_break (FALSE);
 }
