@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "command.h"
 #include "general.h"
@@ -106,11 +106,7 @@ draw_caret (VmaidWindow *vmaid,
     }
   if (timer_id == 0)
     timer_id = gtk_timeout_add (500, signal_timeout, NULL);
-#ifdef G_HAVE_GINT64
-  t = (gint64)vmaid->cursor.frame * vmaid->scale * 1000 / vmaid->rate;
-#else /* not G_HAVE_GINT64 */
-  t = vmaid->cursor.frame * vmaid->scale * 1000 / vmaid->rate;
-#endif /* not G_HAVE_GINT64 */
+  t = (glonglong)vmaid->cursor.frame * vmaid->scale * 1000 / vmaid->rate;
   text = vmaid->select.stream < 0
         ? g_strdup_printf (_("Frame %d  Time %02d:%02d:%02d"),
                                 vmaid->cursor.frame,
@@ -500,19 +496,27 @@ history_operation (VmaidWindow    *vmaid,
   sx = MAX ((vmaid->drawing->allocation.width - 4) / vmaid->width - 2, 1);
   if (vmaid->cursor.frame > max)
     vmaid->cursor.frame = max;
+   /* ja:キャレットが表示されるように調整 */
   if (vmaid->top > vmaid->cursor.frame)
-    vmaid->top = vmaid->cursor.frame;
-  else if (vmaid->top < vmaid->cursor.frame - sx)
+    vmaid->top = MIN (vmaid->cursor.frame, max - sx);
+  if (vmaid->top < vmaid->cursor.frame - sx)
     vmaid->top = MAX (vmaid->cursor.frame - sx, 0);
   set_menu_bar (vmaid);
+  gtk_widget_set_usize (vmaid->drawing, vmaid->width * 3 + 4,
+                        system_font_height * 2 + ((vmaid->avi_edit[0] ? 1 : 0)
+                            + (vmaid->avi_edit[1] ? 1 : 0)) * vmaid->height);
+  gtk_widget_queue_resize (GTK_WIDGET (window));
   gtk_widget_draw (vmaid->drawing, NULL);
+  misc_set_scroll_bar (vmaid->hscroll,
+                                GTK_SIGNAL_FUNC (signal_value_changed_hscroll),
+                                                vmaid, 0, max, sx, vmaid->top);
   draw_caret (vmaid, NULL);
 }
 
 
 /*  ja:ファイルの保存を問い合わせる
     vmaid,ウインドウ情報
-      RET,TRUE:ファイルは閉じる,FALSE:ファイルを閉じない                    */
+      RET,TRUE:ファイルを閉じる,FALSE:ファイルを閉じない                    */
 gboolean
 prompt_close (VmaidWindow *vmaid)
 {
@@ -521,16 +525,27 @@ prompt_close (VmaidWindow *vmaid)
   page = orz_mdi_get_page_from_data (ORZ_MDI (mdi), vmaid);
   if (orz_mdi_get_edited (ORZ_MDI (mdi), page))
     {
-      gchar *text, *utf8str;
+      gchar *utf8str;
+      gint result;
+      GtkWidget *dialog;
 
       utf8str = g_filename_to_utf8
                 (orz_mdi_get_file (ORZ_MDI (mdi), page), -1, NULL, NULL, NULL);
-      text = g_strdup_printf (_("File %s was edited.\nSave?"), utf8str);
+      dialog = gtk_message_dialog_new (GTK_WINDOW (window),
+                            GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
+                            GTK_MESSAGE_INFO, GTK_BUTTONS_NONE,
+                            _("File %s was edited.\nSave?"), utf8str);
       g_free (utf8str);
-      switch (misc_message_box ("Video maid", text, 0,
-                                    _("_Yes"), _("_No"), _("Cancel"), NULL))
+      gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+                                        GTK_STOCK_YES, GTK_RESPONSE_YES,
+                                        GTK_STOCK_NO, GTK_RESPONSE_NO,
+                                        GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
+                                        NULL);
+      result = gtk_dialog_run (GTK_DIALOG (dialog));
+      gtk_widget_destroy (dialog);
+      switch (result)
         {
-          case 0:
+          case GTK_RESPONSE_YES:
             {
               gint page_num;
 
@@ -545,12 +560,12 @@ prompt_close (VmaidWindow *vmaid)
               if (!orz_mdi_get_edited (ORZ_MDI (mdi), page))
                 break;
             }
-          case 2:
-          case -1:
-            g_free (text);
+            return FALSE;
+          case GTK_RESPONSE_NO:
+            break;
+          default:
             return FALSE;
         }
-      g_free (text);
     }
   return TRUE;
 }
@@ -571,13 +586,8 @@ gint get_max_frame (VmaidWindow *vmaid,
   gint max0, max1;
 
   max0 = vmaid->avi_edit[0] ? avi_length (vmaid->avi_edit[0]) - 1 : 0;
-#ifdef G_HAVE_GINT64
-  max1 = vmaid->avi_edit[1] ? (gint64)avi_length_time (vmaid->avi_edit[1])
-                        * vmaid->rate / ((gint64)vmaid->scale * 1000) - 1 : 0;
-#else /* not G_HAVE_GINT64 */
-  max1 = vmaid->avi_edit[1] ? avi_length_time (vmaid->avi_edit[1])
-                                * vmaid->rate / (vmaid->scale * 1000) - 1 : 0;
-#endif /* not G_HAVE_GINT64 */
+  max1 = vmaid->avi_edit[1] ? (glonglong)avi_length_time (vmaid->avi_edit[1])
+                    * vmaid->rate / ((glonglong)vmaid->scale * 1000) - 1 : 0;
   switch (stream)
     {
       case 0: return max0;
