@@ -14,12 +14,15 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "general.h"
 #include "thread.h"
 #include "toolbar.h"
-#include "misc/misc_mdi.h"
+#include "orz/orzmdi.h"
+#ifndef USE_THREAD
+#include "misc/misc.h"
+#endif /* not USE_THREAD */
 #include <time.h>
 
 
@@ -39,28 +42,25 @@ thread_set_menu_bar (gboolean task)
 {
   gint i;
   GList *glist;
-  GtkWidget *menu;
+  GtkWidget *menu_shell;
 
-  menu = gtk_item_factory_get_widget (ifactory_menu, "<main>/File");
-  glist = gtk_container_children (GTK_CONTAINER (menu));
-  for (i = g_list_length(glist) - 2; i >= 0; i--)
+  menu_shell = misc_find_menu (menu_entries, "/file/");
+  glist = gtk_container_children (GTK_CONTAINER (menu_shell));
+  for (i = g_list_length (glist) - 2; i >= 0; i--)
     gtk_widget_set_sensitive (GTK_WIDGET (g_list_nth_data (glist, i)), task);
   g_list_free (glist);
-  gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-        (gtk_item_factory_get_widget (ifactory_menu, "<main>/Edit"))), task);
-  gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-        (gtk_item_factory_get_widget (ifactory_menu, "<main>/View"))), task);
-  gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-        (gtk_item_factory_get_widget (ifactory_menu, "<main>/Option"))), task);
-  gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-        (gtk_item_factory_get_widget (ifactory_menu, "<main>/Window"))), task);
-  gtk_widget_set_sensitive (gtk_menu_get_attach_widget (GTK_MENU
-        (gtk_item_factory_get_widget (ifactory_menu, "<main>/Help"))), task);
-  for (i = 0; toolbar_items[i].name != (gpointer)-1; i++)
-    if (toolbar_items[i].item)
-      gtk_widget_set_sensitive (toolbar_items[i].item, task);
+  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/edit"), task);
+  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/view"), task);
+  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/option"), task);
+  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/task"), !task);
+  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/window"), task);
+  gtk_widget_set_sensitive (misc_find_menu (menu_entries, "/help"), task);
+  for (i = 0; toolbar_entries[i].path; i++)
+    if (toolbar_entries[i].tool_item)
+      gtk_widget_set_sensitive (GTK_WIDGET (toolbar_entries[i].tool_item),
+                                                                        task);
   if (task)
-    set_menu_bar ((VmaidWindow *)misc_mdi_get_data (MISC_MDI (mdi), -1));
+    set_menu_bar ((VmaidWindow *)orz_mdi_get_data (ORZ_MDI (mdi), -1));
 }
 #endif /* not USE_THREAD */
 
@@ -117,8 +117,8 @@ thread_insert (gint         id,
   gtk_list_store_set (list_store, &iter, 4, tl, -1);
   gtk_tree_view_columns_autosize (GTK_TREE_VIEW (tview));
 #ifdef USE_THREAD
-  critical = FALSE;
   gdk_threads_leave ();
+  critical = FALSE;
   G_UNLOCK (critical);
 #endif /* USE_THREAD */
   g_free (text[1]);
@@ -243,13 +243,13 @@ thread_idling (gint       id,
       /* ja:中断ではなくかつ進行状況が異なるとき */
       tl->percent = percent;
       text = percent >= 0
-                    ? g_strdup_printf ("%d",percent) : g_strdup (_("Error"));
+                    ? g_strdup_printf ("%d", percent) : g_strdup (_("Error"));
       gtk_list_store_set (list_store, &iter, 3, text, -1);
       g_free (text);
     }
 #ifdef USE_THREAD
-  critical = FALSE;
   gdk_threads_leave ();
+  critical = FALSE;
   G_UNLOCK (critical);
 #else /* not USE_THREAD */
   while (gtk_events_pending ())
@@ -273,7 +273,6 @@ thread_break (const gboolean all)
 #ifdef USE_THREAD
   G_LOCK (critical);
   critical = TRUE;
-  gdk_threads_enter ();
 #endif /* USE_THREAD */
   select = gtk_tree_view_get_selection (GTK_TREE_VIEW (tview));
   for (i = 0; gtk_tree_model_iter_nth_child (GTK_TREE_MODEL (list_store),
@@ -288,7 +287,6 @@ thread_break (const gboolean all)
           }
       }
 #ifdef USE_THREAD
-  gdk_threads_leave ();
   critical = FALSE;
   G_UNLOCK (critical);
 #endif /* USE_THREAD */
@@ -364,7 +362,7 @@ close_program (void)
             }
         }
       /* ja:MDIの子ウインドウ数 */
-      length = misc_mdi_get_n_pages (MISC_MDI (mdi));
+      length = orz_mdi_get_n_pages (ORZ_MDI (mdi));
 
 #ifdef USE_THREAD
       gdk_threads_leave ();
@@ -372,7 +370,7 @@ close_program (void)
       G_UNLOCK (critical);
 
       /* ja:リストに終了があり、このスレッド以外ならばこのスレッドは破棄 */
-      if (result || !thread_idling(id,0))
+      if (result || !thread_idling (id, 0))
         {
           thread_delete (id);
           return NULL;
