@@ -14,9 +14,10 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #include "version.h"
+#include "avicore/acm.h"
 #include "avicore/icm.h"
 #include "misc/gnugpl.h"
 #include <gdk/gdkkeysyms.h>
@@ -34,14 +35,12 @@ version_dialog_changed (GtkTreeSelection *select,
 {
   GtkTreeIter iter;
   GtkTreeModel *model;
-  GtkTreeView *tview;
   IcmObject *icm_object = NULL;
+  AcmObject *acm_object = NULL;
 
   if (gtk_tree_selection_get_selected (select, &model, &iter))
-    gtk_tree_model_get (model, &iter, 3, &icm_object, -1);
-  tview = gtk_tree_selection_get_tree_view (select);
-  g_object_set_data (G_OBJECT (tview), "user_data", icm_object);
-  gtk_widget_set_sensitive (button, icm_object != NULL);
+    gtk_tree_model_get (model, &iter, 3, &icm_object, 4, &acm_object, -1);
+  gtk_widget_set_sensitive (button, icm_object || acm_object);
 }
 
 
@@ -53,20 +52,36 @@ version_dialog_row_deleted (GtkTreeModel *model,
 {
   GtkTreeIter iter;
   IcmObject *icm_object;
+  AcmObject *acm_object;
 
   gtk_tree_model_get_iter (model, &iter, path);
-  gtk_tree_model_get (model, &iter, 3, &icm_object, -1);
+  gtk_tree_model_get (model, &iter, 3, &icm_object, 4, &acm_object, -1);
   if (icm_object)
     icm_close (icm_object);
+  if (acm_object)
+    acm_close (acm_object);
 }
 
 
 /* ja:Aboutボタンが押された */
 static void
-version_dialog_clicked (GtkWidget *widget,
-                        GtkWidget *tview)
+version_dialog_clicked (GtkWidget        *widget,
+                        GtkTreeSelection *select)
 {
-  icm_dialog_about (g_object_get_data (G_OBJECT (tview), "user_data"));
+  GtkTreeIter iter;
+  GtkTreeModel *model;
+
+  if (gtk_tree_selection_get_selected (select, &model, &iter))
+    {
+      IcmObject *icm_object;
+      AcmObject *acm_object;
+
+      gtk_tree_model_get (model, &iter, 3, &icm_object, 4, &acm_object, -1);
+      if (icm_object)
+        icm_dialog_about (icm_object);
+      else if (acm_object)
+        acm_dialog_about (acm_object);
+    }
 }
 
 
@@ -90,7 +105,8 @@ version_dialog_button_press (GtkWidget      *widget,
           if (gtk_tree_model_get_iter (gtk_tree_view_get_model
                                         (GTK_TREE_VIEW (widget)), &iter, path))
             {
-              version_dialog_clicked (widget, widget);
+              version_dialog_clicked (widget,
+                        gtk_tree_view_get_selection (GTK_TREE_VIEW (widget)));
               result = TRUE;
             }
           gtk_tree_path_free (path);
@@ -126,8 +142,8 @@ version_dialog (void)
   GtkTreeViewColumn *column;
   GtkWidget *button, *notebook, *text, *tview;
   GtkWidget *dialog, *scroll, *hbox0, *hbox1 ,*vbox;
-const static gchar *str[3] = {N_("Name"), N_("Code"), N_("Attribute")};
-const static gchar *authors =
+  const static gchar *str[3] = {N_("Name"), N_("Code"), N_("Attribute")};
+  const static gchar *authors =
 "Main Program :\n"
 "    Kazuki IWAMOTO\n"
 "Document :\n"
@@ -253,13 +269,14 @@ const static gchar *vmaid_xpm[] = {
   /* ja:ボタン */
   button = gtk_button_new_with_mnemonic (_("_About..."));
   /* ja:ツリービュー */
-  store = gtk_tree_store_new (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
-                                                            G_TYPE_POINTER);
+  store = gtk_tree_store_new (5, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING,
+                                            G_TYPE_POINTER, G_TYPE_POINTER);
   gtk_tree_store_append (store, &iter_parent, NULL);
   gtk_tree_store_set (store, &iter_parent,  0, _("Video Compressor"),
                                             1, NULL,
                                             2, NULL,
                                             3, NULL,
+                                            4, NULL,
                                             -1);
   glist = icm_get_handler_list ();
   if (glist)
@@ -271,7 +288,7 @@ const static gchar *vmaid_xpm[] = {
         {
           IcmObject *icm_object;
 
-          icm_object = icm_open ((guint32)g_list_nth_data (glist, i),
+          icm_object = icm_open (GPOINTER_TO_UINT (g_list_nth_data (glist, i)),
                                                             ICM_MODE_QUERY);
           if (icm_object)
             {
@@ -304,13 +321,82 @@ const static gchar *vmaid_xpm[] = {
                                                     1, handler,
                                                     2, attribute,
                                                     3, NULL,
+                                                    4, NULL,
                                                     -1);
                   if (icm_is_dialog_about (icm_object))
-                    gtk_tree_store_set (store, &iter, 3, icm_object, -1);
-                  else
-                    icm_close (icm_object);
+                    {
+                      gtk_tree_store_set (store, &iter, 3, icm_object, -1);
+                      icm_object = NULL;
+                    }
                 }
               g_free (handler);
+              if (icm_object)
+                icm_close (icm_object);
+            }
+        }
+      g_list_free (glist);
+    }
+  gtk_tree_store_append (store, &iter_parent, NULL);
+  gtk_tree_store_set (store, &iter_parent,  0, _("Audio Compressor"),
+                                            1, NULL,
+                                            2, NULL,
+                                            3, NULL,
+                                            4, NULL,
+                                            -1);
+  glist = acm_get_tag_list ();
+  if (glist)
+    {
+      gint length;
+
+      length = g_list_length (glist);
+      for (i = 0; i < length; i++)
+        {
+          AcmObject *acm_object;
+
+          acm_object = acm_open
+                    ((guint16)GPOINTER_TO_UINT (g_list_nth_data (glist, i)));
+          if (acm_object)
+            {
+              gchar *handler;
+              const gchar *name, *attribute;
+
+              name = acm_get_name (acm_object);
+              handler = g_strdup_printf ("%04X", acm_get_tag (acm_object));
+              switch (acm_get_attribute (acm_object))
+                {
+                  case ACM_ATTR_NATIVE:
+                    attribute = _("Video maid Native");
+                    break;
+                  case ACM_ATTR_WIN32:
+#ifdef G_OS_WIN32
+                    attribute = _("Win32 Native");
+#else /* not G_OS_WIN32 */
+                    attribute = _("Win32 Emulation");
+#endif /* not G_OS_WIN32 */
+                    break;
+                  default:
+                    attribute = _("Unknown");
+                }
+              if (name && handler)
+                {
+                  GtkTreeIter iter;
+
+                  gtk_tree_store_append (store, &iter, &iter_parent);
+                  gtk_tree_store_set (store, &iter, 0, name,
+                                                    1, handler,
+                                                    2, attribute,
+                                                    3, NULL,
+                                                    4, NULL,
+                                                    -1);
+                  if (acm_is_dialog_about (acm_object))
+                    {
+                      gtk_tree_store_set (store, &iter, 4, acm_object, -1);
+                      acm_object = NULL;
+                    }
+                }
+              g_free (handler);
+              if (acm_object)
+                acm_close (acm_object);
             }
         }
       g_list_free (glist);
@@ -344,7 +430,7 @@ const static gchar *vmaid_xpm[] = {
   gtk_container_add (GTK_CONTAINER (scroll), tview);
   /* ja:ボタン */
   g_signal_connect (G_OBJECT (button), "clicked",
-                                G_CALLBACK (version_dialog_clicked), tview);
+                                G_CALLBACK (version_dialog_clicked), select);
   gtk_widget_set_sensitive (button, FALSE);
   GTK_WIDGET_SET_FLAGS (button, GTK_CAN_DEFAULT);
   /* ja:フレームとボックス */
