@@ -14,7 +14,7 @@
 
     You should have received a copy of the GNU General Public License
     along with this program; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */
 #ifndef __VMAID_H__
 #define __VMAID_H__
@@ -34,24 +34,24 @@ extern "C" {
 #endif /* __cplusplus */
 
 
-#define VMAID_VERSION_NOTICE "Video maid "VERSION" ("VMAID_BUILD_ENVIRONMENT")"
+#define VMAID_VERSION_NOTICE "Video maid "VERSION" ("BUILD_ENVIRONMENT")"
 #define VMAID_COPYRIGHT_NOTICE "Copyright (C) 1998-2005 Kazuki IWAMOTO"
 
 #define MENUFILE 9
 
 
-typedef struct VmaidCursor_Tag
+typedef struct _VmaidCursor
 {
   gint stream;                  /* ja:ストリームの位置(0,1) */
   gint frame;                   /* ja:現在の位置(0...) */
 } VmaidCursor;
-typedef struct VmaidHistory_Tag
+typedef struct _VmaidHistory
 {
   AviEdit *avi_edit[2];         /* ja:AVI編集 */
   VmaidCursor cursor, select;
-  struct VmaidHistory_Tag *next;
+  struct _VmaidHistory *next;
 } VmaidHistory;
-typedef struct VmaidWindow_Tag
+typedef struct _VmaidWindow
 {
   gint top;                     /* ja:ウインドウの先頭 */
   gint width, height;           /* ja:フレームのサイズ */
@@ -75,7 +75,7 @@ enum
 extern gboolean caret;                  /* ja:キャレットの形 */
 extern gboolean newfile;                /* ja:TRUE:新規ファイル,FALSE:なし */
 extern gboolean second;                 /* ja:TRUE:新規,FALSE:既存 */
-extern gboolean default_ratio;          /* ja:TRUE:縦/横の比率を保持しない */
+extern gboolean default_ratio;          /* ja:TRUE:縦/横の比率を保持する */
 extern gboolean file_merge;             /* ja:TRUE:連番,FALSE:単独 */
 extern gchar *open_path;                /* ja:開くのパス */
 extern gchar *save_path;                /* ja:名前を付けて保存のパス */
@@ -112,4 +112,4 @@ extern MiscCreateMenuEntry tview_entries[];
 #endif /* __cplusplus */
 
 
-#endif
+#endif /* __VMAID_H__ */
